@@ -8,6 +8,7 @@ import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsLockedException;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTSessionExpiredException;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.TabResource;
+import org.gcube.portlets.user.td.widgetcommonevent.client.CommonMessages;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.SessionExpiredType;
 import org.gcube.portlets.user.td.wizardwidget.client.WizardCard;
@@ -59,10 +60,18 @@ import com.sencha.gxt.widget.core.client.menu.MenuItem;
 import com.sencha.gxt.widget.core.client.toolbar.LabelToolItem;
 import com.sencha.gxt.widget.core.client.toolbar.ToolBar;
 
+/**
+ * 
+ * @author giancarlo
+ * email: <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
+ *
+ */
 public class TabResourcesSelectionPanel extends ContentPanel implements
 		HasSelectionHandlers<TabResource> {
 	private static final DateTimeFormat sdf = DateTimeFormat
 			.getFormat("yyyy-MM-dd HH:mm");
+	private CommonMessages msgsCommon;
+	private UnionWizardMessages msgs;
 	private Grid<TabResource> grid;
 	private ResourceBundle res;
 	private Menu contextMenu;
@@ -70,12 +79,14 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 	private TabResource removableTR;
 
 	private WizardCard parent;
+	
 
 	public TabResourcesSelectionPanel(WizardCard parent, ResourceBundle res) {
 		this.res = res;
 		this.parent = parent;
 		Log.debug("TabResourcesSelectionPanel");
-		init();
+		initMessages();
+		initPanel();
 		try {
 			createContextMenu();
 			buildPanel();
@@ -86,7 +97,12 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 		}
 	}
 
-	protected void init() {
+	protected void initMessages() {
+		msgsCommon = GWT.create(CommonMessages.class);
+		msgs = GWT.create(UnionWizardMessages.class);
+	}
+
+	protected void initPanel() {
 		setHeaderVisible(false);
 		// new Resizable(this, Dir.E, Dir.SE, Dir.S);
 
@@ -95,14 +111,14 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 	protected void buildPanel() {
 
 		ToolBar toolBar = new ToolBar();
-		toolBar.add(new LabelToolItem("Search: "));
+		toolBar.add(new LabelToolItem(msgsCommon.toolItemSearchLabel()));
 		final TextField searchField = new TextField();
 		toolBar.add(searchField);
 
 		TextButton btnReload = new TextButton();
 		// btnReload.setText("Reload");
 		btnReload.setIcon(res.refresh16());
-		btnReload.setToolTip("Reload");
+		btnReload.setToolTip(msgsCommon.toolItemReloadLabel());
 		toolBar.add(btnReload);
 
 		IdentityValueProvider<TabResource> identity = new IdentityValueProvider<TabResource>();
@@ -112,17 +128,17 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 				.create(TabResourceProperties.class);
 
 		ColumnConfig<TabResource, String> nameColumn = new ColumnConfig<TabResource, String>(
-				properties.name(), 90, "Name");
+				properties.name(), 90, msgs.nameColumn());
 		ColumnConfig<TabResource, String> typeColumn = new ColumnConfig<TabResource, String>(
-				properties.tabResourceType(), 30, "Type");
+				properties.tabResourceType(), 30, msgs.typeColumn());
 		ColumnConfig<TabResource, String> tableTypeNameColumn = new ColumnConfig<TabResource, String>(
-				properties.tableTypeName(), 30, "Table Type");
+				properties.tableTypeName(), 30, msgs.tableTypeColumn());
 		ColumnConfig<TabResource, String> agencyColumn = new ColumnConfig<TabResource, String>(
-				properties.agency(), 60, "Agency");
+				properties.agency(), 60, msgs.agencyColumn());
 		ColumnConfig<TabResource, String> ownerColumn = new ColumnConfig<TabResource, String>(
-				properties.ownerLogin(), 70, "Owner");
+				properties.ownerLogin(), 70, msgs.ownerColumn());
 		ColumnConfig<TabResource, Date> dateColumn = new ColumnConfig<TabResource, Date>(
-				properties.date(), 50, "Creation Date");
+				properties.date(), 50, msgs.creationDateColumn());
 
 		dateColumn.setCell(new DateCell(sdf));
 
@@ -218,7 +234,7 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 
 	protected void createContextMenu() {
 		contextMenu = new Menu();
-		MenuItem deleteTRItem = new MenuItem("Delete");
+		MenuItem deleteTRItem = new MenuItem(msgs.itemDelete());
 		deleteTRItem.setId("DeleteTR");
 		deleteTRItem
 				.setIcon(org.gcube.portlets.user.td.unionwizardwidget.client.resources.UnionResourceBundle.INSTANCE
@@ -273,8 +289,9 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 							Log.debug("Error retrieving tabular resource: "
 									+ caught.getLocalizedMessage());
 							UtilsGXT3
-									.alert("Error!",
-											"Error retrieving tabular resources on server!");
+									.alert(msgsCommon.error(),
+											msgs.errorRetrievingTabularResources()
+											);
 						}
 						callback.onFailure(caught);
 					}
@@ -313,10 +330,14 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 		grid.getLoader().load();
 	}
 
+	public void gridDeselectAll(){
+		grid.getSelectionModel().deselectAll();
+	}
+	
 	protected void deleteTR(TabResource tabResource) {
 		removableTR = tabResource;
-		final ConfirmMessageBox mb = new ConfirmMessageBox("Delete",
-				"Would you like to delete this tabular resource?");
+		final ConfirmMessageBox mb = new ConfirmMessageBox(msgs.delete(),
+				msgs.woultYouLikeToDeleteThisTabularResource());
 
 		/* Next in GXT 3.1.1 */
 
@@ -369,13 +390,13 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 						} else {
 							if (caught instanceof TDGWTIsLockedException) {
 								Log.error(caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error Locked",
+								UtilsGXT3.alert(msgsCommon.errorLocked(),
 										caught.getLocalizedMessage());
 							} else {
 								Log.error("Error on delete TabResource: "
 										+ caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error",
-										"Error on delete TabResource: "
+								UtilsGXT3.alert(msgsCommon.error(),
+										msgs.errorOnDeleteTabularResourceFixed()
 												+ caught.getLocalizedMessage());
 							}
 						}
