@@ -10,6 +10,7 @@ import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTSessionExpire
 import org.gcube.portlets.user.td.gwtservice.shared.tr.union.UnionSession;
 import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialog;
 import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialogListener;
+import org.gcube.portlets.user.td.widgetcommonevent.client.CommonMessages;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.SessionExpiredType;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.OperationResult;
@@ -17,6 +18,7 @@ import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 import org.gcube.portlets.user.td.wizardwidget.client.WizardCard;
 
 import com.allen_sauer.gwt.log.client.Log;
+import com.google.gwt.core.client.GWT;
 import com.google.gwt.safehtml.shared.SafeHtmlBuilder;
 import com.google.gwt.user.client.Command;
 import com.google.gwt.user.client.rpc.AsyncCallback;
@@ -37,18 +39,18 @@ import com.sencha.gxt.widget.core.client.container.VBoxLayoutContainer.VBoxLayou
  */
 public class UnionOperationInProgressCard extends WizardCard implements
 		MonitorDialogListener {
-
-	protected UnionOperationInProgressCard thisCard;
-	protected UnionSession unionSession;
-	protected TRId newTrId;
-	protected HtmlLayoutContainer resultField;
+	private static CommonMessages msgsCommon=GWT.create(CommonMessages.class);
+	private UnionWizardMessages msgs;
+	private UnionSession unionSession;
+	private TRId newTrId;
+	private HtmlLayoutContainer resultField;
+	
 
 	public UnionOperationInProgressCard(final UnionSession unionSession) {
-		super("Operation In Progress", "");
-
+		super(msgsCommon.operationInProgress(), "");
 		this.unionSession = unionSession;
-		thisCard = this;
-
+		initMessages();
+		
 		VBoxLayoutContainer operationInProgressPanel = new VBoxLayoutContainer();
 		operationInProgressPanel.setVBoxLayoutAlign(VBoxLayoutAlign.CENTER);
 
@@ -58,21 +60,21 @@ public class UnionOperationInProgressCard extends WizardCard implements
 		description.setBorderWidth(0);
 
 		description.setHTML(0, 0,
-				"<span style=\"font-weight:bold;\";>Union with: </span>");
+				"<span style=\"font-weight:bold;\";>"+msgs.unionWithFixed()+"</span>");
 		description.setText(0, 1, unionSession.getUnionTabularResource()
 				.getName());
 		description.setHTML(1, 0,
-				"<span style=\"font-weight:bold;\";>Type: </span>");
+				"<span style=\"font-weight:bold;\";>"+msgs.typeFixed()+"</span>");
 		description.setText(1, 1, unionSession.getUnionTabularResource()
 				.getTableTypeName());
 
 		description.setHTML(2, 0,
-				"<span style=\"font-weight:bold;\";>Owner: </span>");
+				"<span style=\"font-weight:bold;\";>"+msgs.ownerFixed()+"</span>");
 		description.setText(2, 1, unionSession.getUnionTabularResource()
 				.getOwnerLogin());
 
 		FramedPanel summary = new FramedPanel();
-		summary.setHeadingText("Union Summary");
+		summary.setHeadingText(msgs.summaryUnion());
 		summary.setWidth(400);
 		summary.add(description);
 		operationInProgressPanel.add(summary, new BoxLayoutData(new Margins(20,
@@ -87,7 +89,11 @@ public class UnionOperationInProgressCard extends WizardCard implements
 		resultField.setVisible(false);
 
 	}
-
+	
+	protected void initMessages(){
+		msgs = GWT.create(UnionWizardMessages.class);
+	}
+	
 	/**
 	 * 
 	 */
@@ -109,18 +115,18 @@ public class UnionOperationInProgressCard extends WizardCard implements
 						} else {
 							if (caught instanceof TDGWTIsLockedException) {
 								Log.error(caught.getLocalizedMessage());
-								showErrorAndHide("Error Locked",
+								showErrorAndHide(msgsCommon.errorLocked(),
 										caught.getLocalizedMessage(), "",
 										caught);
 							} else {
 								if (caught instanceof TDGWTIsFinalException) {
 									Log.error(caught.getLocalizedMessage());
-									showErrorAndHide("Error Final",
+									showErrorAndHide(msgsCommon.errorFinal(),
 											caught.getLocalizedMessage(), "",
 											caught);
 								} else {
-									showErrorAndHide("Error in Union",
-											"An error occured in union.",
+									showErrorAndHide(msgsCommon.error(),
+											msgs.errorInUnionFixed(),
 											caught.getLocalizedMessage(),
 											caught);
 								}
@@ -152,7 +158,7 @@ public class UnionOperationInProgressCard extends WizardCard implements
 		newTrId = operationResult.getTrId();
 		SafeHtmlBuilder safeHtmlBuilder = new SafeHtmlBuilder();
 		safeHtmlBuilder
-				.appendHtmlConstant("<div style='text-align:center;font-size:large;font-weight:bold; color:#009900;'>Operation Completed</div>");
+				.appendHtmlConstant("<div style='text-align:center;font-size:large;font-weight:bold; color:#009900;'>"+msgsCommon.operationCompleted()+"</div>");
 		resultField.setHTML(safeHtmlBuilder.toSafeHtml());
 		resultField.setVisible(true);
 		Command sayComplete = new Command() {
@@ -181,7 +187,7 @@ public class UnionOperationInProgressCard extends WizardCard implements
 	public void operationFailed(Throwable caught, String reason, String details) {
 		SafeHtmlBuilder safeHtmlBuilder = new SafeHtmlBuilder();
 		safeHtmlBuilder
-				.appendHtmlConstant("<div style='text-align:center;font-size:large;font-weight:bold;color:red;'>Operation Failed</div>");
+				.appendHtmlConstant("<div style='text-align:center;font-size:large;font-weight:bold;color:red;'>"+msgsCommon.operationFailed()+"</div>");
 		resultField.setHTML(safeHtmlBuilder.toSafeHtml());
 		resultField.setVisible(true);
 		if (caught instanceof TDGWTSessionExpiredException) {
@@ -190,7 +196,7 @@ public class UnionOperationInProgressCard extends WizardCard implements
 							new SessionExpiredEvent(
 									SessionExpiredType.EXPIREDONSERVER));
 		} else {
-			showErrorAndHide("Error in Union", reason, details, caught);
+			showErrorAndHide(msgsCommon.error(), reason, details, caught);
 
 		}
 		forceLayout();
@@ -201,7 +207,7 @@ public class UnionOperationInProgressCard extends WizardCard implements
 		newTrId = operationResult.getTrId();
 		SafeHtmlBuilder safeHtmlBuilder = new SafeHtmlBuilder();
 		safeHtmlBuilder
-				.appendHtmlConstant("<div style='text-align:center;font-size:large;font-weight:bold;color: #FF9900;'>Validation Failed</div>");
+				.appendHtmlConstant("<div style='text-align:center;font-size:large;font-weight:bold;color: #FF9900;'>"+msgsCommon.validationFailed()+"</div>");
 		resultField.setHTML(safeHtmlBuilder.toSafeHtml());
 		resultField.setVisible(true);
 
@@ -232,7 +238,7 @@ public class UnionOperationInProgressCard extends WizardCard implements
 	public void operationAborted() {
 		SafeHtmlBuilder safeHtmlBuilder = new SafeHtmlBuilder();
 		safeHtmlBuilder
-				.appendHtmlConstant("<div style='text-align:center;font-size:large;font-weight:bold;color: #AA00AA;'>Operation Aborted</div>");
+				.appendHtmlConstant("<div style='text-align:center;font-size:large;font-weight:bold;color: #AA00AA;'>"+msgsCommon.operationAborted()+"</div>");
 		resultField.setHTML(safeHtmlBuilder.toSafeHtml());
 		resultField.setVisible(true);
 
@@ -262,7 +268,7 @@ public class UnionOperationInProgressCard extends WizardCard implements
 	public void operationPutInBackground() {
 		SafeHtmlBuilder safeHtmlBuilder = new SafeHtmlBuilder();
 		safeHtmlBuilder
-				.appendHtmlConstant("<div style='text-align:center;font-size:large;font-weight:bold;color: #00AAAA;'>Operation in Background</div>");
+				.appendHtmlConstant("<div style='text-align:center;font-size:large;font-weight:bold;color: #00AAAA;'>"+msgsCommon.operationInBackground()+"</div>");
 		resultField.setHTML(safeHtmlBuilder.toSafeHtml());
 		resultField.setVisible(true);
 
