@@ -14,17 +14,15 @@ import com.google.web.bindery.event.shared.EventBus;
  * 
  */
 public class UnionWizardTD extends WizardWindow {
-	protected static final int WITHWIZARD = 720;
-	protected static final int HEIGHTWIZARD = 520;
-
-	protected UnionSession unionSession;
-	protected TRId trId;
+	private static final int WITHWIZARD = 800;
+	private static final int HEIGHTWIZARD = 520;
+	private UnionSession unionSession;
 
 	/**
 	 * 
-	 * @param trId
-	 * @param title
-	 * @param eventBus
+	 * @param trId tabular resource id
+	 * @param title wizard title
+	 * @param eventBus event bus
 	 */
 	public UnionWizardTD(TRId trId, String title, EventBus eventBus) {
 		super(title, eventBus);
@@ -32,7 +30,6 @@ public class UnionWizardTD extends WizardWindow {
 		setWidth(WITHWIZARD);
 		setHeight(HEIGHTWIZARD);
 
-		this.trId = trId;
 		unionSession = new UnionSession();
 		unionSession.setTrId(trId);
 
